@@ -19,7 +19,7 @@ from pdm.cli.utils import (
 from pdm.exceptions import NoPythonVersion, PdmUsageError, ProjectError
 from pdm.formats import FORMATS
 from pdm.installers.installers import format_dist
-from pdm.iostream import stream
+from pdm.iostream import LOCK, stream
 from pdm.models.builders import EnvBuilder
 from pdm.models.candidates import Candidate
 from pdm.models.requirements import Requirement, parse_requirement, strip_extras
@@ -50,17 +50,19 @@ def do_lock(
         requirements = [
             r for deps in project.all_dependencies.values() for r in deps.values()
         ]
-
-    with stream.open_spinner(
-        title="Resolving dependencies", spinner="dots"
-    ) as spin, stream.logging("lock"):
-        reporter = project.get_reporter(requirements, tracked_names, spin)
-        resolver = project.core.resolver_class(provider, reporter)
-        mapping, dependencies, summaries = resolve(
-            resolver, requirements, project.environment.python_requires
-        )
-        data = format_lockfile(mapping, dependencies, summaries)
-        spin.succeed("Resolution success")
+    with stream.logging("lock"):
+        # The context managers are nested to ensure the spinner is stopped before
+        # any message is thrown to the output.
+        with stream.open_spinner(
+            title="Resolving dependencies", spinner="dots"
+        ) as spin:
+            reporter = project.get_reporter(requirements, tracked_names, spin)
+            resolver = project.core.resolver_class(provider, reporter)
+            mapping, dependencies, summaries = resolve(
+                resolver, requirements, project.environment.python_requires
+            )
+            data = format_lockfile(mapping, dependencies, summaries)
+            spin.succeed(f"{LOCK} Lock successful")
     project.write_lockfile(data)
 
     return mapping
@@ -495,7 +497,7 @@ def do_import(project: Project, filename: str, format: Optional[str] = None) ->
         project.pyproject = {"tool": {"pdm": {}}}
     project.tool_settings.update(tool_settings)
     project.pyproject["build-system"] = {
-        "requires": ["pdm"],
+        "requires": ["pdm-pep517"],
         "build-backend": ["pdm.pep517.api"],
     }
     project.write_pyproject()
