@@ -20,7 +20,6 @@ from pdm._types import CandidateInfo
 from pdm.cli.actions import do_init, do_use
 from pdm.core import main
 from pdm.exceptions import CandidateInfoNotFound
-from pdm.iostream import stream
 from pdm.models.candidates import Candidate
 from pdm.models.environment import Environment
 from pdm.models.repositories import BaseRepository
@@ -30,7 +29,7 @@ from pdm.project.config import Config
 from pdm.utils import cached_property, get_finder, temp_environ
 from tests import FIXTURES
 
-stream.disable_colors()
+os.environ["CI"] = "1"
 
 
 class LocalFileAdapter(requests.adapters.BaseAdapter):
@@ -290,5 +289,5 @@ def is_dev(request):
 
 @pytest.fixture()
 def invoke():
-    runner = CliRunner()
+    runner = CliRunner(mix_stderr=False)
     return functools.partial(runner.invoke, main, prog_name="pdm")
